==> spirit_hub-0.0.1.6.tar.gz: spirit_hub-0.0.1.6/app/components/tagsets/informed_badges_component.rb <==
# frozen_string_literal: true

module Tagsets
  class InformedBadgesComponent < ViewComponent::Base
    attr_reader :tagset, :show_limit

    def initialize(tagset:, show_limit: 4)
      super
      @tagset = tagset
      @show_limit = show_limit
    end

    def informed_targets
      @informed_targets ||= InformedTarget.load_list(tagset.informed)
    end

    def informed_targets_count
      @informed_targets_count ||= informed_targets.count
    end

    def informed_targets_main
      @informed_targets_main ||= InformedTarget.load_list(tagset.informed_main)
    end

    def informed_targets_cc
      @informed_targets_cc ||= InformedTarget.load_list(tagset.informed_cc)
    end

    def informed_targets_bcc
      @informed_targets_bcc ||= InformedTarget.load_list(tagset.informed_bcc)
    end

    def informed_targets_avatars
      @informed_targets_avatars ||= begin
        avatars = informed_targets.take(show_limit).sort_by(&:first_name).map do |target|
          if target.picture_url.present?
            tag.img(
              src: target.picture_url,
              class: 'rounded-full w-6 h-6 bg-[#E6EAEC] border border-white',
              style: 'margin-right: -5%'
            )
          else
            tag.div(
              target.initials,
              class: 'rounded-full w-6 h-6 bg-[#E6EAEC] border border-white text-white text-[#909399] bg-spirit-orange flex justify-center items-center leading-[13px]',
              style: 'margin-right: -5%'
            )
          end
        end

        if avatars_overflow?
          hidden_targets_count = informed_targets_count - (show_limit - 1)

          avatars[-1] = tag.div(
            "+#{hidden_targets_count}",
            class: 'rounded-full w-6 h-6 bg-[#E6EAEC] border border-white text-[#909399] flex justify-center items-center font-bold text-[10px] leading-[13px]'
          )
        end

        avatars
      end
    end

    private

    def avatars_overflow?
      informed_targets_count > show_limit
    end

    class InformedTarget
      def self.load_list(tagset_informed_ids)
        users = ::User.where(:id.in => tagset_informed_ids).only(:first_name, :last_name, :picture_url)
        # Informed ids can be formatted as Klass#id to map generic targets
        contact_ids = tagset_informed_ids.select { _1.to_s.start_with?('Doc#') }.map { _1.split('#').last }
        contacts = ::Doc.where(:id.in => contact_ids)

        users.map { self::User.new(_1) } + contacts.map { self::Contact.new(_1) }
      end

      def initialize(target)
        @target = target
      end

      def initials
        [first_name.to_s[0], last_name.to_s[0]].join.upcase
      end

      class User < InformedTarget
        delegate :first_name, :last_name, :full_name, :picture_url, to: :@target
      end

      class Contact < InformedTarget
        def first_name
          @target.superfields['given_name'].presence
        end

        def last_name
          @target.superfields['surname'].presence
        end

        def full_name
          [first_name, last_name].join(' ') if first_name && last_name

          @target.title
        end

        def initials
          return super if first_name && last_name

          @target.title[0..1].upcase
        end

        def picture_url
          nil
        end
      end
    end
  end
end

==> spirit_hub-0.0.1.8.tar.gz: spirit_hub-0.0.1.8/app/components/tagsets/informed_badges_component.rb <==
# frozen_string_literal: true

module Tagsets
  class InformedBadgesComponent < ViewComponent::Base
    attr_reader :tagset, :show_limit

    def initialize(tagset:, show_limit: 4)
      super
      @tagset = tagset
      @show_limit = show_limit
    end

    def informed_targets
      @informed_targets ||= InformedTarget.load_list(tagset.informed)
    end

    def informed_targets_count
      @informed_targets_count ||= informed_targets.count
    end

    def informed_targets_main
      @informed_targets_main ||= InformedTarget.load_list(tagset.informed_main)
    end

    def informed_targets_cc
      @informed_targets_cc ||= InformedTarget.load_list(tagset.informed_cc)
    end

    def informed_targets_bcc
      @informed_targets_bcc ||= InformedTarget.load_list(tagset.informed_bcc)
    end

    def informed_targets_avatars
      @informed_targets_avatars ||= begin
        avatars = informed_targets.take(show_limit).sort_by(&:full_name).map do |target|
          if target.picture_url.present?
            tag.img(
              src: target.picture_url,
              class: 'rounded-full w-6 h-6 bg-[#E6EAEC] border border-white',
              style: 'margin-right: -5%'
            )
          else
            tag.div(
              target.initials,
              class: 'rounded-full w-6 h-6 bg-[#E6EAEC] border border-white text-white text-[#909399] bg-spirit-orange flex justify-center items-center leading-[13px]',
              style: 'margin-right: -5%'
            )
          end
        end

        if avatars_overflow?
          hidden_targets_count = informed_targets_count - (show_limit - 1)

          avatars[-1] = tag.div(
            "+#{hidden_targets_count}",
            class: 'rounded-full w-6 h-6 bg-[#E6EAEC] border border-white text-[#909399] flex justify-center items-center font-bold text-[10px] leading-[13px]'
          )
        end

        avatars
      end
    end

    private

    def avatars_overflow?
      informed_targets_count > show_limit
    end

    class InformedTarget
      def self.load_list(tagset_informed_ids)
        users = ::User.where(:id.in => tagset_informed_ids).only(:first_name, :last_name, :picture_url)
        # Informed ids can be formatted as Klass#id to map generic targets
        contact_ids = tagset_informed_ids.select { _1.to_s.start_with?('Doc#') }.map { _1.split('#').last }
        contacts = ::Doc.where(:id.in => contact_ids)

        users.map { self::User.new(_1) } + contacts.map { self::Contact.new(_1) }
      end

      def initialize(target)
        @target = target
      end

      def initials
        [first_name.to_s[0], last_name.to_s[0]].join.upcase
      end

      class User < InformedTarget
        delegate :first_name, :last_name, :full_name, :picture_url, to: :@target
      end

      class Contact < InformedTarget
        def first_name
          @target.superfields['given_name'].presence
        end

        def last_name
          @target.superfields['surname'].presence
        end

        def full_name
          [first_name, last_name].join(' ') if first_name && last_name

          @target.title
        end

        def initials
          return super if first_name && last_name

          @target.title[0..1].upcase
        end

        def picture_url
          nil
        end
      end
    end
  end
end
